==> linter-0.1.107.tar.gz: test/_data/directives_ordering/sort_directive_sections_alphabetically/bad.dart <==
// Copyright (c) 2017, the Dart project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:html'; // OK
import 'dart:isolate'; // OK
import 'dart:convert'; // LINT
import 'dart:math'; // OK

import 'package:async/src/async_cache.dart'; // OK
import 'package:yaml/yaml.dart'; // OK
import 'package:charcode/ascii.dart'; // LINT
import 'package:analyzer/analyzer.dart'; // LINT

import 'package:linter/src/analyzer.dart'; // OK
import 'package:linter/src/ast.dart'; // OK
import 'package:linter/src/rules.dart'; // OK
import 'package:linter/src/formatter.dart'; // LINT

import 'dummy4.dart'; // OK
import 'dummy4.dart'; // OK
import 'dummy3.dart'; // LINT
import 'dummy3.dart'; // OK
import 'dummy2.dart'; // LINT
import 'dummy2.dart'; // OK
import 'dummy1.dart'; // LINT
import 'dummy1.dart'; // OK

export 'dart:isolate'; // OK
export 'dart:convert'; // LINT
export 'dart:math'; // OK

export 'package:async/src/async_cache.dart'; // OK
export 'package:yaml/yaml.dart'; // OK
export 'package:charcode/ascii.dart'; // LINT
export 'package:analyzer/analyzer.dart'; // LINT

export 'package:linter/src/analyzer.dart'; // OK
export 'package:linter/src/ast.dart'; // OK
export 'package:linter/src/rules.dart'; // OK
export 'package:linter/src/formatter.dart'; // LINT

export 'dummy4.dart'; // OK
export 'dummy1.dart'; // LINT
export 'dummy2.dart'; // OK
export 'dummy3.dart'; // OK

==> linter-1.2.1.tar.gz: test/_data/directives_ordering/sort_directive_sections_alphabetically/bad.dart <==
// Copyright (c) 2017, the Dart project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:html'; // OK
import 'dart:isolate'; // OK
import 'dart:convert'; // LINT
import 'dart:math'; // OK

import 'package:async/src/async_cache.dart'; // OK
import 'package:yaml/yaml.dart'; // OK
import 'package:charcode/ascii.dart'; // LINT
import 'package:async/async.dart'; // LINT

import 'package:linter/src/analyzer.dart'; // OK
import 'package:linter/src/ast.dart'; // OK
import 'package:linter/src/rules.dart'; // OK
import 'package:linter/src/formatter.dart'; // LINT

import 'dummy4.dart'; // OK
import 'dummy4.dart'; // OK
import 'dummy3.dart'; // LINT
import 'dummy3.dart'; // OK
import 'dummy2.dart'; // LINT
import 'dummy2.dart'; // OK
import 'dummy1.dart'; // LINT
import 'dummy1.dart'; // OK

export 'dart:isolate'; // OK
export 'dart:convert'; // LINT
export 'dart:math'; // OK

export 'package:async/src/async_cache.dart'; // OK
export 'package:yaml/yaml.dart'; // OK
export 'package:charcode/ascii.dart'; // LINT
export 'package:async/async.dart'; // LINT

export 'package:linter/src/analyzer.dart'; // OK
export 'package:linter/src/ast.dart'; // OK
export 'package:linter/src/rules.dart'; // OK
export 'package:linter/src/formatter.dart'; // LINT

export 'dummy4.dart'; // OK
export 'dummy1.dart'; // LINT
export 'dummy2.dart'; // OK
export 'dummy3.dart'; // OK
